agentti.core


add-worker!clj

(add-worker! config)

Register and start a worker. See agentti.lifecycle/add-worker! for options.

Register and start a worker. See `agentti.lifecycle/add-worker!` for options.
sourceraw docstring

get-workerclj

(get-worker name)

Return the raw worker entry for name, or nil.

Return the raw worker entry for `name`, or nil.
sourceraw docstring

list-workersclj

(list-workers)

Return a vector of worker status maps for admin/dashboards.

Return a vector of worker status maps for admin/dashboards.
sourceraw docstring

registry-snapshotclj

(registry-snapshot)

Return a snapshot of the internal worker registry (name->entry). Intended for debugging/tests; dashboards should usually prefer list-workers.

Return a snapshot of the internal worker registry (name->entry).
Intended for debugging/tests; dashboards should usually prefer `list-workers`.
sourceraw docstring

stop-all-workers!clj

(stop-all-workers!)

Stops all registered workers. Initiates a graceful shutdown, falling back to a forced interrupt if a worker does not exit within 3 seconds. Returns a map of {worker-name -> true|nil}.

Stops all registered workers. Initiates a graceful shutdown, falling back
to a forced interrupt if a worker does not exit within 3 seconds.
Returns a map of {worker-name -> true|nil}.
sourceraw docstring

stop-worker!clj

(stop-worker! name)

Stops a worker by name. Initiates a graceful shutdown, falling back to a forced interrupt if the worker does not exit within 3 seconds.

Stops a worker by name. Initiates a graceful shutdown, falling back
to a forced interrupt if the worker does not exit within 3 seconds.
sourceraw docstring

worker-exists?clj

(worker-exists? name)

True if a worker named name exists.

True if a worker named `name` exists.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries