(add-worker! config)Register and start a worker. See agentti.lifecycle/add-worker! for options.
Register and start a worker. See `agentti.lifecycle/add-worker!` for options.
(get-worker name)Return the raw worker entry for name, or nil.
Return the raw worker entry for `name`, or nil.
(list-workers)Return a vector of worker status maps for admin/dashboards.
Return a vector of worker status maps for admin/dashboards.
(registry-snapshot)Return a snapshot of the internal worker registry (name->entry).
Intended for debugging/tests; dashboards should usually prefer list-workers.
Return a snapshot of the internal worker registry (name->entry). Intended for debugging/tests; dashboards should usually prefer `list-workers`.
(stop-all-workers!)Stops all registered workers. Initiates a graceful shutdown, falling back to a forced interrupt if a worker does not exit within 3 seconds. Returns a map of {worker-name -> true|nil}.
Stops all registered workers. Initiates a graceful shutdown, falling back
to a forced interrupt if a worker does not exit within 3 seconds.
Returns a map of {worker-name -> true|nil}.(stop-worker! name)Stops a worker by name. Initiates a graceful shutdown, falling back to a forced interrupt if the worker does not exit within 3 seconds.
Stops a worker by name. Initiates a graceful shutdown, falling back to a forced interrupt if the worker does not exit within 3 seconds.
(worker-exists? name)True if a worker named name exists.
True if a worker named `name` exists.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |